@@ -14,7 +14,7 @@
 
 #define SOUNDLIB_VERSION_MAJOR		0
 #define SOUNDLIB_VERSION_MINOR		0
-#define SOUNDLIB_VERSION_SUBMINOR	2
+#define SOUNDLIB_VERSION_SUBMINOR	4
 #define SOUNDLIB_VERSION		( ( LIBULTRA_VERSION_MAJOR << 16 ) | ( LIBULTRA_VERSION_MINOR << 8 ) | LIB_ULTRA_VERSION_SUBMINOR )
 
 /*
@@ -80,6 +80,7 @@ int snd_mixer_close( void *handle );
 int snd_mixer_file_descriptor( void *handle );
 int snd_mixer_channels( void *handle );
 int snd_mixer_info( void *handle, snd_mixer_info_t *info );
+int snd_mixer_exact_mode( void *handle, int enable );
 int snd_mixer_channel( void *handle, const char *channel_id );
 int snd_mixer_channel_info( void *handle, int channel, snd_mixer_channel_info_t *info );
 int snd_mixer_channel_read( void *handle, int channel, snd_mixer_channel_t *data );
@@ -123,6 +124,8 @@ int snd_pcm_record_status( void *handle, snd_pcm_record_status_t *status );
 int snd_pcm_drain_playback( void *handle );
 int snd_pcm_flush_playback( void *handle );
 int snd_pcm_flush_record( void *handle );
+int snd_pcm_playback_time( void *handle, int enable );
+int snd_pcm_record_time( void *handle, int enable );
 ssize_t snd_pcm_write( void *handle, const void *buffer, size_t size );
 ssize_t snd_pcm_read( void *handle, void *buffer, size_t size );
 
